# -*- coding: utf-8 -*-
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Gaetan Delannay <gaetan.delannay at easi.wallonie.be>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from DateTime import DateTime
from Products.Archetypes.atapi import *
from config import *
import os, time, os.path
import appy.pod.renderer
from Products.MasterSelectWidget.MasterSelectWidget import MasterSelectWidget

from Avis import AvisOdt

# ------------------------------------------------------------------------------
def slaveFields(action, *slaves):
    '''Helps to define more smartly the slave fields of a master field
       (MasterSelectWidget). The master is always a "yes/no" field.
       If p_action is:
       - "showIfYes": slaves will be shown when master is "yes" ;
       - "showIfNo": slaves will be shown when master is "no" ;
       - "setValue": it defines slaves whose values may change depending on
         actions on the master. '''
    res = []
    for slave in slaves:
        slaveDict = {'name': slave}
        if action == "showIfYes":
            slaveDict.update({'action': 'show', 'hide_values': ['yes'] })
        elif action == "showIfNo":
            slaveDict.update({'action': 'show', 'hide_values': ['no'] })
        elif action == "setValue":
            sName = slave[:-7]
            slaveDict.update({'action': 'value',
                              'vocab_method': 'defo%s' % sName,
                              'control_param': '%sCP' % sName})
        res.append(slaveDict)
    return tuple(res)

# ------------------------------------------------------------------------------
# Default values for "analysis" fields.

defaultAnalysisValues = {
    'delaiOrdre': \
        {'yes': u"Le texte en projet prévoit des délais d'ordre à l'article...",
         'no': ''
        },
    'delaiRigueur': \
        {'yes': u"Le texte en projet prévoit des délais de rigueur à l'article...",
         'no': ''
        },
    'delaiAccuse': \
        {'yes': u"Le texte en projet prévoit des délais d'accusés de réception à l'article...",
         'no': ''
        },
    'envoiTermes': \
        {'yes': u'Différents termes sont utilisés pour définir les envois:...',
         'no': u'Les envois sont exprimés par le même terme.'
        },
    'envoiModalites': \
        {'yes': u"Les modalités d'envoi sont prévues à l'article...",
         'no': u'Le texte en projet ne précise pas la nature des envois.'
        },
    'envoiRecommande': \
        {'yes': u"Des envois recommandés sont prévus à l'article...",
         'no': ''
        },
    'piecesJustificativesDemandees': \
        {'yes': u"Le texte en projet requiert l'adjonction de pièces justificatives à l'article...",
         'no': ''
        },
    'simulRenvoi': \
        {'yes': u"Un renvoi de modalités est prévu à l'article...",
         'no': ''
        },
    'simulCirculaire': \
        {'yes': "",
         'no': ""
        },
    'simulBrochure': \
        {'yes': "",
         'no': ''
        },
    'acteursProcedure': \
        {'yes': "",
         'no': ''
        },
    'acteursImpact': \
        {'yes': u"Le texte en projet va sans conteste générer de nouvelles obligations pour...",
         'no': ''
        },
    'delegationPrevue': \
        {'yes': u"Une délégation est prévue à l'article...",
         'no': ''
        },
    'lisibiliteProblemes': \
        {'yes':u"Le texte est clair à lire ... L'ensemble des termes spécifiques sont définis " \
               u"à l'article 1er du texte en projet, ce qui permet une bonne compréhension du " \
               u"texte ... Le texte en projet présent une structure claire et apparente, ce " \
               u"qui permet une lecture aisée du texte ... Les termes utilisés sont usuels ..." \
               u"Le texte en projet forme un tout cohérent ... L'abrogation de ...  et son " \
               u"remplacement par ... est également un gage de lisibilité tant pour l'usager " \
               u"que pour l'administration.",
         'no': u"Le texte est clair à lire ... L'ensemble des termes spécifiques sont définis " \
               u"à l'article 1er du texte en projet, ce qui permet une bonne compréhension du " \
               u"texte ... Le texte en projet présent une structure claire et apparente, ce " \
               u"qui permet une lecture aisée du texte ... Les termes utilisés sont usuels ..." \
               u"Le texte en projet forme un tout cohérent ... L'abrogation de ...  et son " \
               u"remplacement par ... est également un gage de lisibilité tant pour l'usager " \
               u"que pour l'administration."
        },
    'formulairePrevu': \
        {'yes': u"Un formulaire est prévu.",
         'no': ''
        },
    'formulaireAttache': \
        {'yes': '',
         'no': ''
        },
    'testKafkaKo': \
        {'yes': u"Le test Kafka pourrait être amélioré...",
         'no': u'Le test Kafka est bien rempli.'
        },
    'charges': \
        {'yes': '',
         'no': ''
        },
}

defaultRecommandationsValues = {
    'piecesJustificativesDemandeesRecommandations': "",
    'lisibiliteProblemesRecommandations': "",
    'delegationPrevueRecommandations': "",
}

schema = Schema((

    # Attributs liés au texte en projet ----------------------------------------

    StringField(
        name='apType',
        widget=SelectionWidget(
            label="Type de norme",
            format="select",
            label_msgid='Avis_label_apType',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary=DisplayList(( ('arreteGouv', u'arrêté du Gouvernement wallon'),
                                 ('arreteMin', u'arrêté ministériel'),
                                 ('decret', u'décret') )),
        required=True
    ),

    StringField(
        name='apTitle',
        widget=TextAreaWidget(
            label=u"Intitulé de la norme",
            rows=3,
            label_msgid='Avis_label_apTitle',
            i18n_domain='Avis',
        ),
        required=True
    ),

    StringField(
        name='apDescription',
        widget=TextAreaWidget(
            label=u"Contexte",
            rows=5,
            label_msgid='Avis_label_apDescription',
            i18n_domain='Avis',
        )
    ),

    # Les délais ---------------------------------------------------------------

    StringField(
        name='delai',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question des délais ?",
            slave_fields= slaveFields('showIfYes',
                'delaiOrdre', 'delaiOrdreAnalyse', 'delaiRigueur',
                'delaiRigueurAnalyse', 'delaiAccuse', 'delaiAccuseAnalyse'),
            label_msgid='Avis_label_delai',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='delaiOrdre',
        widget=MasterSelectWidget(
            label=u"Y a-t-il des délais d'ordre définis, et ce de manière satisfaisante ?",
            slave_fields=slaveFields('setValue', 'delaiOrdreAnalyse'),
            label_msgid='Avis_label_delaiOrdre',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='delaiOrdreAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_delaiOrdreAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['delaiOrdre']['no']
    ),

    StringField(
        name='delaiRigueur',
        widget=MasterSelectWidget(
            label=u"Y a-t-il des délais de rigueur définis, et ce de manière satisfaisante ?",
            slave_fields=slaveFields('setValue', 'delaiRigueurAnalyse'),
            label_msgid='Avis_label_delaiRigueur',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='delaiRigueurAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_delaiRigueurAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['delaiRigueur']['no']
    ),

    StringField(
        name='delaiAccuse',
        widget=MasterSelectWidget(
            label=u"Y a-t-il un délai d'accusé de réception défini, et ce de manière satisfaisante ?",
            slave_fields=slaveFields('setValue', 'delaiAccuseAnalyse'),
            label_msgid='Avis_label_delaiAccuse',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='delaiAccuseAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_delaiAccuseAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['delaiAccuse']['no']
    ),

    # Les envois ---------------------------------------------------------------

    StringField(
        name='envoi',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question de la transmission de documents ?",
            slave_fields= slaveFields('showIfYes',
                'envoiTermes', 'envoiTermesAnalyse', 'envoiModalites',
                'envoiModalitesAnalyse', 'envoiRecommande', 'envoiRecommandeAnalyse'),
            label_msgid='Avis_label_envoi',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='envoiTermes',
        widget=MasterSelectWidget(
            label=u"Y a-t-il des différences dans les termes utilisés pour exprimer les envois ?",
            slave_fields=slaveFields('setValue', 'envoiTermesAnalyse'),
            label_msgid='Avis_label_envoiTermes',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='envoiTermesAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_envoiTermesAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['envoiTermes']['no']
    ),

    StringField(
        name='envoiModalites',
        widget=MasterSelectWidget(
            label=u"Les modalités d'envoi sont-elles définies ?",
            slave_fields=slaveFields('setValue', 'envoiModalitesAnalyse'),
            label_msgid='Avis_label_envoiModalites',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='envoiModalitesAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_envoiModalitesAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['envoiModalites']['no']
    ),

    StringField(
        name='envoiRecommande',
        widget=MasterSelectWidget(
            label=u"Y a-t-il des envois recommandés ?",
            slave_fields=slaveFields('setValue', 'envoiRecommandeAnalyse'),
            label_msgid='Avis_label_envoiRecommande',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='envoiRecommandeAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_envoiRecommandeAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['envoiRecommande']['no']
    ),

    # Les pièces justificatives ------------------------------------------------

    StringField(
        name='piecesJustificatives',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question des pièces justificatives ?",
            slave_fields= slaveFields('showIfYes', 'piecesJustificativesDemandees',
                                      'piecesJustificativesDemandeesAnalyse'),
            label_msgid='Avis_label_piecesJustificatives',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='piecesJustificativesDemandees',
        widget=MasterSelectWidget(
            label=u"Des pièces justificatives sont-elles demandées ?",
            slave_fields=slaveFields('setValue', 'piecesJustificativesDemandeesAnalyse') + \
                         slaveFields('showIfYes', 'piecesJustificativesDemandeesRecommandations'),
            label_msgid='Avis_label_piecesJustificativesDemandees',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='piecesJustificativesDemandeesAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_piecesJustificativesDemandeesAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['piecesJustificativesDemandees']['no']
    ),

    TextField(
        name='piecesJustificativesDemandeesRecommandations',
        widget=TextAreaWidget(
            label=u"Recommandation(s)",
            label_msgid='Avis_label_piecesJustificativesDemandeesRecommandations',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultRecommandationsValues['piecesJustificativesDemandeesRecommandations']
    ),

    # La simultanéité des textes -----------------------------------------------

    StringField(
        name='simultaneite',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question de la simultanéité des textes ?",
            slave_fields= slaveFields('showIfYes',
                'simulRenvoi', 'simulRenvoiAnalyse', 'simulCirculaire',
                'simulCirculaireAnalyse', 'simulBrochure', 'simulBrochureAnalyse'),
            label_msgid='Avis_label_simultaneite',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='simulRenvoi',
        widget=MasterSelectWidget(
            label=u"Y a-t-il renvoi de modalité vers un niveau de réglementation inférieur ?",
            slave_fields=slaveFields('setValue', 'simulRenvoiAnalyse'),
            label_msgid='Avis_label_simulRenvoi',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='simulRenvoiAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_simulRenvoiAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['simulRenvoi']['no']
    ),

    StringField(
        name='simulCirculaire',
        widget=MasterSelectWidget(
            label=u"Une information est-elle nécessaire pour les Administrations (Circulaire) ?",
            slave_fields=slaveFields('setValue', 'simulCirculaireAnalyse'),
            label_msgid='Avis_label_simulCirculaire',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='simulCirculaireAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_simulCirculaireAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['simulCirculaire']['no']
    ),

    StringField(
        name='simulBrochure',
        widget=MasterSelectWidget(
            label=u"Une information est-elle nécessaire pour les usagers (brochure) ?",
            slave_fields=slaveFields('setValue', 'simulBrochureAnalyse'),
            label_msgid='Avis_label_simulBrochure',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='simulBrochureAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_simulBrochureAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['simulBrochure']['no']
    ),

    # La prise en compte des acteurs -------------------------------------------

    StringField(
        name='acteurs',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question de la prise en compte des acteurs ?",
            slave_fields= slaveFields('showIfYes',
                'acteursProcedure', 'acteursProcedureAnalyse', 'acteursImpact',
                'acteursImpactAnalyse'),
            label_msgid='Avis_label_acteurs',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='acteursProcedure',
        widget=MasterSelectWidget(
            label=u"Y a-t-il une procédure de prise en compte des acteurs prévue ?",
            slave_fields=slaveFields('setValue', 'acteursProcedureAnalyse'),
            label_msgid='Avis_label_acteursProcedure',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='acteursProcedureAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_acteursProcedureAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['acteursProcedure']['no']
    ),

    StringField(
        name='acteursImpact',
        widget=MasterSelectWidget(
            label=u"Y a-t-il un impact logistique et/ou organisationnel pour l'Administration ?",
            slave_fields=slaveFields('setValue', 'acteursImpactAnalyse'),
            label_msgid='Avis_label_acteursImpact',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='acteursImpactAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_acteursImpactAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['acteursImpact']['no']
    ),

    # Délégation ---------------------------------------------------------------

    StringField(
        name='delegation',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question de la délégation ?",
            slave_fields= slaveFields('showIfYes', 'delegationPrevue',
                                      'delegationPrevueAnalyse'),
            label_msgid='Avis_label_delegation',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='delegationPrevue',
        widget=MasterSelectWidget(
            label=u"Des délégations sont-elles prévues de manière suffisante ?",
            slave_fields=slaveFields('setValue', 'delegationPrevueAnalyse') + \
                         slaveFields('showIfNo', 'delegationPrevueRecommandations'),
            label_msgid='Avis_label_delegationPrevue',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponsesInversed',
        required=True
    ),

    TextField(
        name='delegationPrevueAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_delegationPrevueAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['delegationPrevue']['no']
    ),

    TextField(
        name='delegationPrevueRecommandations',
        widget=TextAreaWidget(
            label=u"Recommandation(s)",
            label_msgid='Avis_label_delegationPrevueRecommandations',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultRecommandationsValues['delegationPrevueRecommandations']
    ),

    # Lisibilité ---------------------------------------------------------------

    StringField(
        name='lisibilite',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question de la lisibilité ?",
            slave_fields= slaveFields('showIfYes',
                'lisibiliteProblemes', 'lisibiliteProblemesAnalyse'),
            label_msgid='Avis_label_lisibilite',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='lisibiliteProblemes',
        widget=MasterSelectWidget(
            label=u"Y a-t-il des problèmes de lisibilité ?",
            slave_fields= slaveFields('showIfYes', 'lisibiliteProblemesRecommandations') + \
                          slaveFields('setValue', 'lisibiliteProblemesAnalyse'),
            label_msgid='Avis_label_lisibiliteProblemes',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='lisibiliteProblemesAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_lisibiliteProblemesAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['lisibiliteProblemes']['no']
    ),

    TextField(
        name='lisibiliteProblemesRecommandations',
        widget=TextAreaWidget(
            label=u"Recommandation(s)",
            label_msgid='Avis_label_lisibiliteProblemesRecommandations',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultRecommandationsValues['lisibiliteProblemesRecommandations']
    ),

    # Formulaires --------------------------------------------------------------

    StringField(
        name='formulaires',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question des formulaires ?",
            slave_fields= slaveFields('showIfYes',
                'formulairePrevu', 'formulairePrevuAnalyse',
                'formulaireAttache', 'formulaireAttacheAnalyse'),
            label_msgid='Avis_label_delegation',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='formulairePrevu',
        widget=MasterSelectWidget(
            label=u"Un formulaire est-il prévu ?",
            slave_fields=slaveFields('setValue', 'formulairePrevuAnalyse'),
            label_msgid='Avis_label_formulairePrevu',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='formulairePrevuAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_formulairePrevuAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['formulairePrevu']['no']
    ),

    StringField(
        name='formulaireAttache',
        widget=MasterSelectWidget(
            label=u"Le formulaire est-il attaché au texte ?",
            slave_fields=slaveFields('setValue', 'formulaireAttacheAnalyse'),
            label_msgid='Avis_label_formulaireAttache',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='formulaireAttacheAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_formulaireAttacheAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['formulaireAttache']['no']
    ),

    # Test Kafka et charges administratives ------------------------------------

    StringField(
        name='testKafka',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question du test Kafka ?",
            slave_fields= slaveFields('showIfYes', 'testKafkaKo', 'testKafkaKoAnalyse'),
            label_msgid='Avis_label_testKafka',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    StringField(
        name='testKafkaKo',
        widget=MasterSelectWidget(
            label=u"Le test Kafka pose-t-il problème ?",
            slave_fields=slaveFields('setValue', 'testKafkaKoAnalyse'),
            label_msgid='Avis_label_testKafkaKo',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='testKafkaKoAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_testKafkaAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['testKafkaKo']['no']
    ),

    StringField(
        name='charges',
        widget=MasterSelectWidget(
            label=u"Est-il pertinent d'aborder la question des charges administratives ?",
            slave_fields= slaveFields('showIfYes', 'chargesAnalyse'),
            label_msgid='Avis_label_charges',
            i18n_domain='Avis',
        ),
        enforceVocabulary=True,
        vocabulary='getResponses',
        required=True
    ),

    TextField(
        name='chargesAnalyse',
        widget=TextAreaWidget(
            label=u"Analyse",
            label_msgid='Avis_label_chargesAnalyse',
            i18n_domain='Avis',
        ),
        default_output_type="text/html",
        default=defaultAnalysisValues['charges']['yes']
    ),

),
)

MyBaseSchema = BaseSchema.copy()
AvisSimplif_schema = MyBaseSchema.copy() + schema.copy()

class AvisSimplif(BaseContent, AvisOdt):
    '''Critique orientée simplification d'un texte'''
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseContent,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Avis de simplification'
    meta_type = 'AvisSimplif'
    portal_type = 'AvisSimplif'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 1
    #content_icon = 'Avis.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "AvisSimplif"
    typeDescMsgId = 'description_edit_avis_simplif'

    actions =  (
       {'action': "string:$object_url/generateOdt",
        'category': "document_actions",
        'id': 'asOdt',
        'name': u'Générer en ODT',
        'permissions': ("View",),
        'condition': 'python:1'
       },
       {'action': "string:$object_url/generateDoc",
        'category': "document_actions",
        'id': 'asDoc',
        'name': u'Générer au format Microsoft Word',
        'permissions': ("View",),
        'condition': 'python:1'
       },
    )

    _at_rename_after_creation = True
    schema = AvisSimplif_schema

    security.declarePublic('generateOdt')
    def generateOdt(self, RESPONSE):
        '''Generates the ODT version of this advice.'''
        return self._generate(RESPONSE, 'odt')

    security.declarePublic('generateDoc')
    def generateDoc(self, RESPONSE):
        '''Generates the Doc version of this advice.'''
        return self._generate(RESPONSE, 'doc')

    security.declarePublic('getResponses')
    def getResponses(self):
        """Returns the predefined responses that are possible for each question.
        """
        return DisplayList( (('no', 'Non'), ('yes', 'Oui')) )

    security.declarePublic('getResponsesInversed')
    def getResponsesInversed(self):
        """Returns the predefined responses that are possible for each question.
        """
        return DisplayList( (('yes', 'Oui'), ('no', 'Non')) )

    def isEmpty(self, fieldName):
        '''Is the rich text field p_fieldName empty?'''
        accessor = 'get%s%s' % (fieldName[0].upper(), fieldName[1:])
        fieldContent = getattr(self, accessor)()
        return fieldContent.strip() == ''

    def getCurrentDate(self):
        now = DateTime()
        return now.strftime('%d/%m/%Y')

    def getUserName(self):
        userInfo = self.portal_membership.getMemberById(self.Creator())
        return userInfo.getProperty('fullname').decode('latin-1')

    def getUserEmail(self):
        return '%s@easi.wallonie.be' % self.Creator()

    # Methods for getting default answers to questions -------------------------
    def defodelaiOrdre(self, delaiOrdreCP):
        return defaultAnalysisValues['delaiOrdre'][delaiOrdreCP]

    def defodelaiRigueur(self, delaiRigueurCP):
        return defaultAnalysisValues['delaiRigueur'][delaiRigueurCP]

    def defodelaiAccuse(self, delaiAccuseCP):
        return defaultAnalysisValues['delaiAccuse'][delaiAccuseCP]

    def defoenvoiTermes(self, envoiTermesCP):
        return defaultAnalysisValues['envoiTermes'][envoiTermesCP]

    def defoenvoiModalites(self, envoiModalitesCP):
        return defaultAnalysisValues['envoiModalites'][envoiModalitesCP]

    def defoenvoiRecommande(self, envoiRecommandeCP):
        return defaultAnalysisValues['envoiRecommande'][envoiRecommandeCP]

    def defopiecesJustificativesDemandees(self, piecesJustificativesDemandeesCP):
        return defaultAnalysisValues['piecesJustificativesDemandees'][piecesJustificativesDemandeesCP]

    def defosimulRenvoi(self, simulRenvoiCP):
        return defaultAnalysisValues['simulRenvoi'][simulRenvoiCP]

    def defosimulCirculaire(self, simulCirculaireCP):
        return defaultAnalysisValues['simulCirculaire'][simulCirculaireCP]

    def defosimulBrochure(self, simulBrochureCP):
        return defaultAnalysisValues['simulBrochure'][simulBrochureCP]

    def defoacteursProcedure(self, acteursProcedureCP):
        return defaultAnalysisValues['acteursProcedure'][acteursProcedureCP]

    def defoacteursImpact(self, acteursImpactCP):
        return defaultAnalysisValues['acteursImpact'][acteursImpactCP]

    def defodelegationPrevue(self, delegationPrevueCP):
        return defaultAnalysisValues['delegationPrevue'][delegationPrevueCP]

    def defolisibiliteProblemes(self, lisibiliteProblemesCP):
        return defaultAnalysisValues['lisibiliteProblemes'][lisibiliteProblemesCP]

    def defoformulairePrevu(self, formulairePrevuCP):
        return defaultAnalysisValues['formulairePrevu'][formulairePrevuCP]

    def defoformulaireAttache(self, formulaireAttacheCP):
        return defaultAnalysisValues['formulaireAttache'][formulaireAttacheCP]

    def defotestKafkaKo(self, testKafkaKoCP):
        return defaultAnalysisValues['testKafkaKo'][testKafkaKoCP]

registerType(AvisSimplif, PROJECTNAME)
# end of class AvisSimplif

##code-section module-footer #fill in your manual code here
##/code-section module-footer



